@@ -2,6 +2,7 @@
 use std::fmt;
 use std::ops::{Add, AddAssign, Div, };
 use std::ops::Mul;
+
 use crate::NonZero;
 
 /// A type representing the value `1`.
@@ -21,6 +22,12 @@ impl num_traits::One for One {
     }
 }
 
+impl Default for One {
+    fn default() -> Self {
+        One
+    }
+}
+
 impl Mul<One> for One {
     type Output = Self;
 
